*
*                               STATION DATA
*                               ************
*   You must read stations before using the ATE, DEL, FMC or XMC commands
*   Created for UW network - 6/4/97 Barbara
*   Slightly modified to allow Y2K format: PNL, 11/25/98
*   Changed NC component codes to SEED standard: PNL, 12/9/98
*   Changed Aug 1999 to use multiple velocity models, binary model and station
*     files; used Tony's values for the duration magnitude relation: PNL
*
* Enable year 2000 formats
* ************************
200 T 1900 0

*
* Use new station codes
* *********************
LET 5 2 3 2 2
*
* Choose between HYPOINVERSE and HYPO71 formats.
* 1 = Summary format flag (1 for hypoinverse; 2 for hypo71)
* 2 = Terminator format (1 for hypoinverse; 2 for hypo71;
*     3 for getting trial hypocenter from the header record)
* 3 = Station format flag (1 for hypoinverse; 2 for hypo71;
      3 for new hypoinverse)
* **********************************************************
H71 2 1 3
*
* Read binary file of all stations (Comment out 4/23/07 SDM and us STA)
* *******************************
* RST 'hypoinverse/stas/uw_sta.bin'
STA 'eq/hypoinverse_avo.sta'
*
* Read XMAG corrections
* *********************
* XMC 'hypoinverse/stas/all2.xmc' T 0
*
* Read FMAG corrections
* *********************
* FMC 'hypoinverse/stas/all2.fmc' T 0
*
* UW phony station codes
* ************************
UNK 3 'TCG' 'GPS' 'WWVB'
*
*                           MULTIPLE CRUSTAL MODELS
*                           ***********************
*
* Read multiple model info and station delays (in ascii)
* ******************************************************
@eq/multmod2000.avo
*
*                             MAGNITUDE CHOICES
*                             *****************
*
* Use Eaton for Fmag1 and logA0, Hirshorn for Fmag2
* *************************************************
MAG 1 T 3 1
*
* Set Tony's magnitude constants
* ***********************************
*DUR -1.03 2.10 0 .0 0, 5*0, 9999 1
* Set to Lahr's Coda Magnitude relation:  July 22, 2011
DUR -1.15 2.0 0.0 0.007 0.0, 5*0, 9999 1
*
* Extra distance and depth terms for Eaton
* ****************************************
* DU2 .005 40, .0006 350, .014 10
*
* Zmag of Hirshorn; use -2.06=-.71-1.35
* -1.35 compensates for the 1.35 gain corr used for the 42db Z stations
* *********************************************************************
* DUB -2.06 2.95 0 .001 0, 1  /This comment is required for some reason (BUG!!!)
DUB -2.06 2.95 0 .001 0, 1 2.026 .013 .0037 0 99999 0
*
* Use all components for FMAG1
* ****************************
FC1 'D' 1 'EHZ'
*
* Use low-gain verticals for FMAG2 = Zmag
* Old codes: FC2 'Z' 1 'Z'
* ***************************************
FC2 'Z' 1 'ELZ'
*
* XMAG components and label
* Old codes: XC1 'X' 7 'V' 'Z' 'E' 'N' 'U' 'W' 'X'
* ************************************************
* XC1 'X' 7 'EHZ' 'ELZ' 'ELE' 'ELN' 'EDZ' 'EDN' 'EDE'
*
* Local Magnitude (ml) components and label
* Old codes: XC2 'L' 8 'L' 'M' '1' '2' '3' '4' '5' '6'
* ****************************************************
* XC2 'L' 8 'WLN' 'WLE' 'HHZ' 'HHN' 'HHE' 'BHZ' 'BHN' 'BHE'
*
* Component corrections for Eaton Fmags
* Old codes: FCM 3 'Z' -.06 'E' -.30, 'N' -.30
* ********************************************
* FCM 3 'ELZ' -.06 'ELE' -.30 'ELN' -.30
*
* Component corrections for Eaton Xmags
* Old codes: XCM 2 'V'  .33, 'Z'  .20
* *************************************
* XCM 2 'EHZ' .33, 'ELZ' .20
*
* Preferred magnitudes.
* Minimum number of readings and min, max magnitudes.
* ***************************************************
PRE 1,  1 5 0. 9.
*
*            Guess CHOICES FOR UW based on standard choices for CALNET
*            *********************************************************
*
* Residual weighting
* ******************
RMS 4 .10 2 3
*
* Standard timing error
* *********************
ERR .10
*
* P to S ratio
* ************
POS 1.78
*
* Don't log events to terminal.
* Don't print unweighted stations.
* ********************************
REP F F
*
* Force location of junk events
* *****************************
JUN T
*
* Minimum number of stations
* **************************
MIN 4
*
* Use California region codes
* ***************************
* NET 2
*
* Trial depth
* ***********
ZTR 5 F
*
* Distance weighting
* ******************
DIS 4 15 10.0 25.0
*
*                                OUTPUT FORMAT
*                                *************
*
* Send error messages to terminal
* *******************************
ERF T
*
* No page ejects
* **************
TOP F
*
* No station list or models in printfile
* **************************************
LST 1 1 0
*
* Medium print output each event
* ******************************
KPR 2
*
* You should use the ATE command with the date and time of your first eq.
* using a year of 0 will always work, but is inefficient.
*
* An easy way is to use the ATE command below with a 0 year, then
* follow this command file with your own ATE command:
*    ATE 1* 84 1 1 0 0    This rereads the standard file but loads
*                         attenuations from your starting date.
*
* Use this line if first date is unknown
* **************************************
* ATE 'hypoinverse/stas/all2.atn' 0
*
* Load cal factors for digital stations
* *************************************
* CAL 'hypoinverse/stas/all2.cal' 0
*
* Specify phase format.
* 5 = archive file with shadow cards
* **********************************
COP 5
*
* Set the archive file format.
* 3 = Full format with shadow cards
* *********************************
CAR 3
*
*       for ARC, SUM, and PRT commands
*
* Name the print output file
* NOTE: filename must be enclosed in single-quotes for PRT command
* ****************************************************************
PRT 'hypo.prt'
*
* Name of summary file
* NOTE: filename must be enclosed in single-quotes for SUM command
* ****************************************************************
SUM 'hypo.sum'
*
* Name the archive output file
* NOTE: filename must be enclosed in single-quotes for ARC command
* ****************************************************************
ARC 'hypo.arc'
*
* Set the append flags to T or F.
* 1 = Printout file,
* 2 = Summary file,
* 3 = Archive file.
* *******************************
APP F F F
*

* added by Paul Friberg to avoid having NC values defaulting in
VER 'AV' '01'
